<template>
  <a-card :bordered="false">
    <a-row
      type="flex"
      :gutter="16"
    >
      <a-col
        :md="12"
        :sm="24"
      >
        <div>
          <a-form-item label="故障或操作过程详情：">
            <a-textarea
              allow-clear
              :disabled="true"
              rows="4"
              v-model="faultDetails"
            ></a-textarea>
          </a-form-item>
        </div>
      </a-col>
      <a-col
        :md="12"
        :sm="24"
      >
        <div>
          <a-form-item
            label="故障图片"
            :labelCol="labelCol"
            :wrapperCol="wrapperCol"
          >
            <j-image-upload
              :isMultiple="true"
              :disabled="true"
              v-model="photo"
            ></j-image-upload>
          </a-form-item>
        </div>
      </a-col>
    </a-row>

  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { deleteAction, getAction, downFile, getFileAccessHttpUrl, httpAction } from '@/api/manage'

export default {
  name: 'FaultDescriptionList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
  },
  data() {
    return {
      description: '故障描述管理页面',
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '故障详情',
          align: "center",
          dataIndex: 'faultDetails'
        },
        {
          title: '故障照片',
          align: "center",
          dataIndex: 'photo'
        },
      ],
      url: {
        list: "/eam/faultDescription/list",
      },
      faultId: '',
      faultDetails: '',
      photo: ''
    }
  },
  created() {
  },
  computed: {
  },
  methods: {
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      var params = this.getQueryParams() //查询条件
      this.loading = true
      getAction(this.url.list, params)
        .then(res => {
          if (res.success) {
            //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
            this.dataSource = res.result.records
            if (this.dataSource != null && this.dataSource != "") {
              this.faultDetails = this.dataSource[0].faultDetails
              this.photo = this.dataSource[0].photo
            } else {
              this.faultDetails = ""
              this.photo = ""
            }
            if (res.result.total) {
              this.ipagination.total = res.result.total
            } else {
              this.ipagination.total = 0
            }
            //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          } else {
            this.$message.warning(res.message)
          }
        })
        .finally(() => {
          this.loading = false
        })
    },

  },
  watch: {
    faultId() {
      this.queryParam = {};
      this.queryParam.faultId = this.faultId;
      this.loadData(1);
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>